    import json
    from os.path import dirname, join, normpath
    import os
    import requests
    r = requests.patch (
    	'http://127.0.0.1:50000',
    	data = json.dumps ({
    		"track": "form proposal keys",
    		"fields": {
    			"seed": "5986888b11358bf3d541b41eea5daece1c6eff64130a45fc8b9ca48f3e0e02463c99c5aedc8a847686d669b7d547c18fe448fc5111ca88f4e8",
    			"directory_path": os.getcwd ()
    		}
    	})
    )
    print (r.text)